export interface ITransaction extends IFifteenCustoms {
    serialVersionUID: number;
    key: ITransactionKey;
    operatorID: string;
    workstationID: string;
    businessUnitID: string;
    businessDayDate: string;
    sequenceNumber: number;
    transactionTypeCode: string;
    beginDateTimestamp: string;
    endDateTimestamp: string;
    cancelledFlag: boolean;
    suspendedFlag: boolean;
    trainingFlag: boolean;
    keyedOfflineFlag: string;
    reasonCode: string;
    reasonDescription: string;
    workerID: string;
    workerFirstName: string;
    workerLastName: string;
    softwareVersion: string;
    suspendNumber: string;
    iSOCurrencyCode: string;
    internalSequenceNumber: number;
    fiscalSequenceNumber: string;
    fiscalFlag: boolean;
    fiscalDayNumber: string;
    fiscalPrinterID: string;
    fiscalSignature: string;
    transactionTimestamp: string;
    beginDateTimestampUTC0: string;
    endDateTimestampUTC0: string;
    transactionTimestampUTC0: string;
    transactionAdditionalPrintoutList: Array<ITransactionAdditionalPrintout>;
    transactionAssociationList: Array<ITransactionAssociation>;
    transactionBinaryDataList: Array<ITransactionBinaryData>;
    transactionCategoryList: Array<ITransactionCategory>;
    transactionExtensionList: Array<ITransactionExtension>;
    transactionResourceOverrideList: Array<ITransactionResourceOverride>;
    retailTransaction: Array<IRetailTransaction>;
    controlTransaction: Array<IControlTransaction>;
    tenderControlTransaction: Array<ITenderControlTransaction>;
    endWorkstationID: string;
    transactionAuditEventList: Array<ITransactionAuditEvent>;
}
export interface ITransactionKey {
    serialVersionUID: number;
    businessUnitGroupID: number;
    transactionID: string;
}
export interface IDefaultCustoms {
    xXCustom01: string;
    xXCustom02: string;
    xXCustom03: string;
    xXCustom04: string;
    xXCustom05: string;
}
export interface ITenCustoms extends IDefaultCustoms {
    xXCustom06: string;
    xXCustom07: string;
    xXCustom08: string;
    xXCustom09: string;
    xXCustom10: string;
}
export interface IFifteenCustoms extends ITenCustoms {
    xXCustom11: string;
    xXCustom12: string;
    xXCustom13: string;
    xXCustom14: string;
    xXCustom15: string;
}
export interface IThirtyCustoms extends IFifteenCustoms {
    xXCustom16: string;
    xXCustom17: string;
    xXCustom18: string;
    xXCustom19: string;
    xXCustom20: string;
    xXCustom21: string;
    xXCustom22: string;
    xXCustom23: string;
    xXCustom24: string;
    xXCustom25: string;
    xXCustom26: string;
    xXCustom27: string;
    xXCustom28: string;
    xXCustom29: string;
    xXCustom30: string;
}
export interface ITransactionAdditionalPrintout extends IDefaultCustoms {
    serialVersionUID: number;
    key: ITransactionAdditionalPrintoutKey;
    triggerID: string;
    triggerValue: string;
    reportName: string;
    printoutCount: number;
    printoutContent: string;
}
export interface ITransactionAdditionalPrintoutKey extends ITransactionKey {
    printoutSequenceNumber: number;
}
export interface ITransactionAssociation extends IDefaultCustoms {
    serialVersionUID: number;
    key: ITransactionAssociationKey;
}
export interface ITransactionAssociationKey extends ITransactionKey {
    toTransactionID: string;
    toBusinessUnitGroupID: number;
    transactionAssociationTypeCode: string;
}
export interface ITransactionBinaryData extends IDefaultCustoms {
    serialVersionUID: number;
    key: ITransactionBinaryDataKey;
    name: string;
    content: any;
    contentLength: number;
}
export interface ITransactionBinaryDataKey extends ITransactionKey {
    binaryDataSequenceNumber: number;
}
export interface ITransactionCategory extends IDefaultCustoms {
    key: ITransactionCategoryKey;
}
export interface ITransactionCategoryKey extends ITransactionKey {
    transactionCategoryCode: string;
}
export interface ITransactionExtension extends IDefaultCustoms {
    key: ITransactionExtensionKey;
    extensionValue: string;
}
export interface ITransactionExtensionKey extends ITransactionKey {
    extensionKey: string;
    extensionSequenceNumber: number;
}
export interface ITransactionResourceOverride extends IDefaultCustoms {
    key: ITransactionResourceOverrideKey;
    resourceID: string;
    operatorID: string;
    overrideTimestamp: string;
    entryMethodCode: string;
    approverName: string;
    approverFirstName: string;
    workGroupID: string;
    workerID: string;
    overrideTimestampUTC0: string;
}
export interface ITransactionResourceOverrideKey extends ITransactionKey {
    overrideSequenceNumber: number;
}
export interface IRetailTransaction extends IDefaultCustoms {
    key: IRetailTransactionKey;
    retailTransactionTypeCode: string;
    tillID: number;
    receiptDateTime: string;
    receiptPrintoutFlag: boolean;
    promotionTimestamp: string;
    frequentShopperLostPointsCount: number;
    emailRequestedFlag: boolean;
    emailAddressLocalPart: string;
    emailAddressDomainPart: string;
    invoicePrintoutTypeCode: string;
    invoiceNumber: string;
    receiptDateTimeUTC0: string;
    promotionTimestampUTC0: string;
    retailTransactionLineItemList: Array<IRetailTransactionLineItem>;
    retailTransactionTotalList: Array<IRetailTransactionTotal>;
    retailTransactionPromotionTriggerList: Array<IRetailTransactionPromotionTrigger>;
    retailTransactionExternalTriggerList: Array<IRetailTransactionExternalTrigger>;
    retailTransactionCustomerList: Array<IRetailTransactionCustomer>;
    retailTransactionCouponSummaryList: Array<IRetailTransactionCouponSummary>;
    retailTransactionTaxExemptTrigger: Array<IRetailTransactionTaxExemptTrigger>;
    retailTransactionPromotionPriceDerivationRuleList: Array<IRetailTransactionPromotionPriceDerivationRule>;
    retailTransactionModifierCouponList: Array<IRetailTransactionModifierCoupon>;
    tenderAuthorizationList: Array<ITenderAuthorization>;
    retailTransactionManufacturerCouponSummaryList: Array<IRetailTransactionManufacturerCouponSummary>;
}
export interface IRetailTransactionKey extends ITransactionKey {
}
export interface IRetailTransactionManufacturerCouponSummary extends IDefaultCustoms {
    key: IRetailTransactionManufacturerCouponSummaryKey;
    manufacturerCompanyCode: string;
    manufacturerOfferCode: string;
    keyEnteredFlag: boolean;
    inputCount: number;
    appliedCount: number;
    appliedIntervalCount: number;
    totalAmount: number;
    tenderLineItemSequenceNumber: number;
    saleLineItemValidationList: Array<IRetailTransactionManufacturerCouponValidation>;
}
export interface IRetailTransactionManufacturerCouponSummaryKey extends ITransactionKey {
    manufacturerCouponScanCode: string;
}
export interface IRetailTransactionManufacturerCouponValidation extends IDefaultCustoms {
    key: IRetailTransactionManufacturerCouponValidationKey;
}
export interface IRetailTransactionManufacturerCouponValidationKey extends ITransactionKey {
    manufacturerCouponScanCode: string;
    saleLineItemSequenceNumber: number;
}
export interface ITenderAuthorization extends IDefaultCustoms {
    key: ITenderAuthorizationKey;
    tenderLineItemSequenceNumber: number;
    cardType: string;
    accountNumber: string;
    cardIssueSequenceNumber: string;
    cardExpirationDate: string;
    referenceNumber: string;
    terminalTransactionStatus: number;
    terminalTransactionErrorNumber: number;
    terminalTransactionType: number;
    forceOnlineFlag: boolean;
    requestedAmount: number;
    authorizationDatetime: string;
    terminalTransactionEndTimestamp: string;
    relatedTenderAuthorizatonSequenceNumber: number;
    terminalSequenceNumber: string;
    requestedISOCurrencyNumber: string;
    cardHolderVerificationTypeCode: string;
    tenderAuthorizationTerminalID: number;
    traceNumber: number;
    terminalType: string;
    merchantNumber: string;
    approvalCode: string;
    adjudicationCode: string;
    adjudicationText: string;
    hostAuthorizedFlag: boolean;
    activationSequenceNumber: number;
    terminalTransactionReferenceNumber: string;
    terminalTransactionTypeCode: string;
    terminalTenderDescription: string;
    applicationID: string;
    encryptedPAN: string;
    terminalTransactionCurrencyCode: string;
    authorizationDatetimeUTC0: string;
    terminalTransactionEndTimestampUTC0: string;
    terminalTransactionToken: string;
    internationalBankAccountNumber: string;
    bankIdentifierCode: string;
    creditorID: string;
    mandateID: string;
    prenotificationText: string;
    tenderAuthorizationTerminalID2: string;
}
export interface ITenderAuthorizationKey extends ITransactionKey {
    tenderAuthorizationSequenceNumber: number;
}
export interface IRetailTransactionModifierCoupon extends IDefaultCustoms {
    key: IRetailTransactionModifierCouponKey;
    couponNumber: string;
}
export interface IRetailTransactionModifierCouponKey extends ITransactionKey {
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    couponSequenceNumber: number;
}
export interface IRetailTransactionPromotionPriceDerivationRule extends IFifteenCustoms {
    key: IRetailTransactionPromotionPriceDerivationRuleKey;
    promotionDescription: string;
    receiptPrinterName: string;
    promotionPriceDerivationRuleSequence: string;
    promotionPriceDerivationRuleResolution: string;
    promotionPriceDerivationRuleTypeCode: string;
    transactionControlBreakCode: string;
    priceModificationMethodCode: string;
    priceDerivationRuleDescription: string;
    promotionOriginatorTypeCode: string;
    externalPromotionID: string;
    externalPriceDerivationRuleID: string;
    triggerQuantity: number;
    giftCertificateExpirationDate: string;
    discountMethodCode: string;
    frequentShopperPointsFlag: boolean;
    customerGroupLoyaltyPointsDefaultQuantity: number;
    prohibitPrintFlag: boolean;
    tenderTypeCode: string;
    promotionTypeName: string;
    calculationBase: string;
    pointsConversionAmount: number;
    noEffectOnSubsequentPriceDerivationRulesFlag: boolean;
    prohibitTransactionRelatedPriceDerivationRulesFlag: boolean;
    couponPrintoutID: string;
    couponPrintoutRule: string;
    couponPrintoutText: any;
    exclusiveFlag: boolean;
    requireUserInteractionFlag: boolean;
    considerPreviousPriceDerivationRulesFlag: boolean;
    concurrenceControlVector: string;
    appliedCount: number;
    printoutValidityPeriod: number;
    externalActionID: string;
    externalActionDescription: string;
    externalActionTextList: Array<IRetailTransactionPromotionExternalActionText>;
    externalActionParameterList: Array<IRetailTransactionPromotionExternalActionParameter>;
    calculationBaseSequence: string;
    externalOfferID: string;
    additionalPriceTypeCode: string;
}
export interface IRetailTransactionPromotionPriceDerivationRuleKey extends ITransactionKey {
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
}
export interface IRetailTransactionPromotionExternalActionParameter extends IDefaultCustoms {
    key: IRetailTransactionPromotionExternalActionParameterKey;
    parameterValue: string;
}
export interface IRetailTransactionPromotionExternalActionParameterKey extends ITransactionKey {
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    parameterID: string;
}
export interface IRetailTransactionPromotionExternalActionText extends IDefaultCustoms {
    key: IRetailTransactionPromotionExternalActionTextKey;
    text: string;
}
export interface IRetailTransactionPromotionExternalActionTextKey extends ITransactionKey {
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    textID: string;
    languageID: string;
}
export interface IRetailTransactionTaxExemptTrigger extends IDefaultCustoms {
    key: IRetailTransactionTaxExemptTriggerKey;
    reasonCode: string;
    reasonDescription: string;
    taxCertificateID: string;
}
export interface IRetailTransactionTaxExemptTriggerKey extends ITransactionKey {
}
export interface IRetailTransactionCouponSummary extends IDefaultCustoms {
    key: IRetailTransactionCouponSummaryKey;
    inputCount: number;
    appliedCount: number;
    privilegeType: string;
    privilegeValue: number;
    customerID: string;
    customerAddressTypeCode: string;
    retailTransactionCouponSerialSummaryList: Array<IRetailTransactionCouponSerialSummary>;
}
export interface IRetailTransactionCouponSummaryKey extends IDefaultCustoms {
    couponNumber: string;
}
export interface IRetailTransactionCouponSerialSummary extends IThirtyCustoms {
    key: IRetailTransactionCouponSerialSummaryKey;
    bookingSuccessfulTypeCode: string;
    bookingTransactionUUID: string;
    expirationTimestamp: string;
    expirationTimestampUTC0: string;
    appliedFlag: boolean;
}
export interface IRetailTransactionCouponSerialSummaryKey extends ITransactionKey {
    couponNumber: string;
    couponSerialNumber: string;
}
export interface IRetailTransactionTotal extends IDefaultCustoms {
    key: IRetailTransactionTotalKey;
    amount: number;
}
export interface IRetailTransactionTotalKey extends ITransactionKey {
    transactionTotalTypeCode: string;
}
export interface IRetailTransactionPromotionTrigger extends IDefaultCustoms {
    key: IRetailTransactionPromotionTriggerKey;
    triggerType: string;
    triggerValue: string;
    privilegeType: string;
    privilegeValue: number;
    reasonCode: string;
    reasonDescription: string;
    reference_: string;
    triggerSequenceAddend: number;
}
export interface IRetailTransactionPromotionTriggerKey extends ITransactionKey {
    triggerSequenceNumber: number;
}
export interface IRetailTransactionExternalTrigger extends IDefaultCustoms {
    key: IRetailTransactionExternalTriggerKey;
    triggerAmount: number;
}
export interface IRetailTransactionExternalTriggerKey extends ITransactionKey {
    triggerTypeCode: string;
}
export interface IRetailTransactionLineItem extends IFifteenCustoms {
    key: IRetailTransactionLineItemKey;
    externalCustomerOrderID: string;
    customerOrderSequenceNumber: number;
    beginDateTimestamp: string;
    voidFlag: boolean;
    endDateTimestamp: string;
    entryMethodCode: string;
    retailTransactionLineItemTypeCode: string;
    voidTypeCode: string;
    workstationID: string;
    workstationTypeCode: string;
    keyedOfflineCode: string;
    beginDateTimestampUTC0: string;
    endDateTimestampUTC0: string;
    saleReturnLineItem: Array<ISaleReturnLineItem>;
    tenderLineItem: Array<ITenderLineItem>;
    voidsLineItem: Array<IVoidsLineItem>;
    roundingLineItem: Array<IRoundingLineItem>;
    priceModificationLineItem: Array<IPriceModificationLineItem>;
    loyaltyRewardLineItem: Array<ILoyaltyRewardLineItem>;
    workerDiscountLineItem: Array<IWorkerDiscountLineItem>;
    taxLineItem: Array<ITaxLineItem>;
    giftCertificateLineItem: Array<IGiftCertificateLineItem>;
    prepaidLineItem: Array<IPrepaidLineItem>;
    retailTransactionLineItemFrequentShopperPointsRedemption: Array<IRetailTransactionLineItemFrequentShopperPointsRedemption>;
    retailTransactionLineItemAssociationList: Array<IRetailTransactionLineItemAssociation>;
    retailTransactionLineItemAdditionalParameterList: Array<IRetailTransactionLineItemAdditionalParameter>;
    retailTransactionLineItemBinaryDataList: Array<IRetailTransactionLineItemBinaryData>;
    retailTransactionLineItemI18NTextList: Array<IRetailTransactionLineItemI18NText>;
    retailTransactionLineItemResourceOverrideList: Array<IRetailTransactionLineItemResourceOverride>;
    retailTransactionLineItemExtensionList: Array<IRetailTransactionLineItemExtension>;
    retailTransactionLineItemAuditEventList: Array<IRetailTransactionLineItemAuditEvent>;
}
export interface IRetailTransactionLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IRetailTransactionLineItemAuditEvent extends IDefaultCustoms {
    key: IRetailTransactionLineItemAuditEventKey;
    creationTimestamp: string;
    creationTimestampUTC0: string;
    workstationID: string;
    workstationTypeCode: string;
    eventTypeCode: string;
    content: any;
}
export interface IRetailTransactionLineItemAuditEventKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    eventSequenceNumber: number;
}
export interface IRetailTransactionLineItemExtension extends IDefaultCustoms {
    key: IRetailTransactionLineItemExtensionKey;
    extensionValue: string;
}
export interface IRetailTransactionLineItemExtensionKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    extensionKey: string;
    extensionSequenceNumber: number;
}
export interface IRetailTransactionLineItemResourceOverride extends IDefaultCustoms {
    key: IRetailTransactionLineItemResourceOverrideKey;
    resourceID: string;
    operatorID: string;
    overrideTimestamp: string;
    entryMethodCode: string;
    approverName: string;
    approverFirstName: string;
    workGroupID: string;
    workerID: string;
    overrideTimestampUTC0: string;
}
export interface IRetailTransactionLineItemResourceOverrideKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    resourceOverrideSequenceNumber: number;
}
export interface IRetailTransactionLineItemI18NText extends IDefaultCustoms {
    key: IRetailTransactionLineItemI18NTextKey;
    retailTransactionLineItemSequenceNumber: number;
    textSequenceNumber: number;
    languageID: string;
    category: string;
    text: string;
    pictureFlag: boolean;
}
export interface IRetailTransactionLineItemI18NTextKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    textSequenceNumber: number;
    languageID: string;
    category: string;
}
export interface IRetailTransactionLineItemBinaryData extends IDefaultCustoms {
    key: IRetailTransactionLineItemBinaryDataKey;
    name: string;
    content: any;
    contentLength: number;
}
export interface IRetailTransactionLineItemBinaryDataKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    binaryDataSequenceNumber: number;
}
export interface IRetailTransactionLineItemAdditionalParameter extends IDefaultCustoms {
    key: IRetailTransactionLineItemAdditionalParameterKey;
    parameterName: string;
    parameterValue: string;
}
export interface IRetailTransactionLineItemAdditionalParameterKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    externalParameterID: string;
}
export interface IRetailTransactionLineItemAssociation extends IDefaultCustoms {
    key: IRetailTransactionLineItemAssociationKey;
}
export interface IRetailTransactionLineItemAssociationKey extends ITransactionKey {
    lineItemSequenceNumber: number;
    toTransactionID: string;
    toLineItemSequenceNumber: number;
    lineItemAssociationTypeCode: string;
    toBusinessUnitGroupID: string;
}
export interface IRetailTransactionLineItemFrequentShopperPointsRedemption extends IDefaultCustoms {
    key: IRetailTransactionLineItemFrequentShopperPointsRedemptionKey;
    customerAccountID: string;
    redemptionTransactionID: string;
    frequentShopperPointsRedeemedCount: number;
}
export interface IRetailTransactionLineItemFrequentShopperPointsRedemptionKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IPrepaidLineItem extends IDefaultCustoms {
    key: IPrepaidLineItemKey;
    bookingSuccessfulTypeCode: string;
    prepaidProviderName: string;
    prepaidTransactionID: string;
    externalSystemAdapterName: string;
    prepaidID: string;
}
export interface IPrepaidLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IGiftCertificateLineItem extends IDefaultCustoms {
    key: IGiftCertificateLineItemKey;
    giftCertificateHandlingTypeCode: string;
    giftCertificateTypeCode: string;
    bookingSuccessfulTypeCode: string;
    bookingCancellationTypeCode: string;
    gCSTransactionUUID: string;
    externalSystemAdapterName: string;
    expirationDate: string;
    remainingBalance: number;
    giftCertificateSerialNumber: string;
}
export interface IGiftCertificateLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ITaxLineItem extends IDefaultCustoms {
    key: ITaxLineItemKey;
    taxIncludedInPricesFlag: boolean;
    taxAtSourceFlag: boolean;
    taxablePercent: number;
    taxableAmount: number;
    taxPercent: number;
    taxAmount: number;
    taxGroupRuleID: string;
    taxAuthorityID: string;
    taxAuthorityName: string;
    taxGroupID: string;
    receiptPrintCode: string;
}
export interface ITaxLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IWorkerDiscountLineItem extends IDefaultCustoms {
    key: IWorkerDiscountLineItemKey;
    workerID: string;
    workerFirstName: string;
    workerLastName: string;
}
export interface IWorkerDiscountLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ILoyaltyRewardLineItem extends IDefaultCustoms {
    key: ILoyaltyRewardLineItemKey;
    pointsAwardedCount: number;
    loyaltyRewardTypeCode: string;
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    frequentShopperPointsEarnedAmount: number;
    triggerSequenceNumber: number;
    computationBaseAmount: number;
    externalSystemOriginatorFlag: boolean;
    couponNumber: string;
    couponAmount: number;
    giftCertificateFaceValueAmount: number;
    pointsPercentage: number;
    loyaltyRewardLineItemCouponSerialList: Array<ILoyaltyRewardLineItemCouponSerial>;
}
export interface ILoyaltyRewardLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ILoyaltyRewardLineItemCouponSerial extends IThirtyCustoms {
    key: ILoyaltyRewardLineItemCouponSerialKey;
    couponSerialNumber: string;
    bookingSuccessfulTypeCode: string;
    bookingTransactionUUID: string;
}
export interface ILoyaltyRewardLineItemCouponSerialKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    couponSerialSequenceNumber: number;
}
export interface IPriceModificationLineItem extends IDefaultCustoms {
    key: IPriceModificationLineItemKey;
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    percentage: number;
    roundingAmount: number;
    amount: number;
    proRatedFlag: boolean;
    triggerSequenceNumber: number;
    extendedAmountBeforeModification: number;
    extendedAmountAfterModification: number;
    extraAmount: number;
    externalSystemOriginatorFlag: boolean;
    calculationBaseAmount: number;
}
export interface IPriceModificationLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IRoundingLineItem extends IDefaultCustoms {
    key: IRoundingLineItemKey;
    roundUpFlag: boolean;
    amount: number;
    typeCode: string;
}
export interface IRoundingLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IVoidsLineItem extends IDefaultCustoms {
    key: IVoidsLineItemKey;
    voidsLineItemSequenceNumber: number;
}
export interface IVoidsLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ITenderLineItem extends IFifteenCustoms {
    key: ITenderLineItemKey;
    isChangeFlag: boolean;
    tenderTypeCode: string;
    tenderAccountNumber: string;
    foreignCurrencyAmount: number;
    exchangeRate: number;
    tenderAmount: number;
    tenderGroupCode: string;
    tenderCount: number;
    tenderDescription: string;
    cashbackFlag: boolean;
    foreignISOCurrencyCode: string;
    exchangeRateMultiplyFlag: boolean;
    currencySymbol: string;
    checkTenderLineItem: Array<ICheckTenderLineItem>;
    tipAmount: number;
    tipForeignCurrencyAmount: number;
}
export interface ITenderLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ICheckTenderLineItem extends IDefaultCustoms {
    key: ICheckTenderLineItemKey;
    fullMICR: string;
    checkSequenceNumber: number;
    adjudicationCode: string;
    checkCardNumber: string;
    bankID: string;
    checkAccountNumber: string;
    bankIdentifierCode: string;
    internationalBankAccountNumber: string;
    checkNumber: string;
}
export interface ICheckTenderLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ISaleReturnLineItem extends IFifteenCustoms {
    key: ISaleReturnLineItemKey;
    pOSItemID: string;
    itemID: string;
    pOSDepartmentID: string;
    unitOfMeasureCode: string;
    itemType: string;
    subItemType: string;
    regularUnitPrice: number;
    regularUnitPriceQuantity: number;
    actualUnitPrice: number;
    actualUnitPriceQuantity: number;
    quantity: number;
    units: number;
    extendedAmount: number;
    extendedDiscountAmount: number;
    sellUnitRetailPriceEntryMethodCode: string;
    actionCode: string;
    reasonCode: string;
    itemTraceableUnitID: string;
    quantityInputMethod: string;
    length: number;
    width: number;
    height: number;
    manualWeightInputFlag: boolean;
    receiptText: string;
    receiptDescription: string;
    wICFlag: boolean;
    allowFoodStampFlag: boolean;
    registrationNumber: string;
    negativeLineItemFlag: boolean;
    discountFlag: boolean;
    frequentShopperPointsEligibilityFlag: boolean;
    discountTypeCode: string;
    priceChangeTypeCode: string;
    priceTypeCode: string;
    grandExtendedAmount: number;
    reasonCodeGroupCode: string;
    reasonDescription: string;
    notConsideredByLoyaltyEngineFlag: boolean;
    merchandiseHierarchyGroupName: string;
    merchandiseHierarchyGroupDescription: string;
    itemClassCode: string;
    prohibitTaxExemptFlag: boolean;
    prohibitReturnFlag: boolean;
    warrantyDuration: number;
    depositTypeCode: string;
    taxExemptCode: string;
    invoiceID: string;
    mainPOSItemID: string;
    mainMerchandiseHierarchyGroupIDQualifier: string;
    mainMerchandiseHierarchyGroupID: string;
    taxReductionAmount: number;
    taxGroupID: string;
    taxReceiptPrintCode: string;
    tareCount: number;
    originalTaxGroupID: string;
    manufacturerFamilyCode: string;
    manufacturerCompanyCode: string;
    priceGroupID: string;
    returnLineItem: Array<IReturnLineItem>;
    saleReturnLineItemSalesOrder: Array<ISaleReturnLineItemSalesOrder>;
    serializedUnitModifer: Array<ISerializedUnitModifer>;
    saleReturnLineItemExtensionList: Array<ISaleReturnLineItemExtension>;
    saleReturnLineItemCollectionList: Array<ISaleReturnLineItemCollection>;
    saleReturnLineItemPriceList: Array<ISaleReturnLineItemPrice>;
    saleReturnTaxLineItemList: Array<ISaleReturnTaxLineItem>;
    lineItemAssociate: Array<ILineItemAssociate>;
    retailPriceModifierList: Array<IRetailPriceModifier>;
    frequentShopperPointsModifierList: Array<IFrequentShopperPointsModifier>;
    saleReturnLineItemPromotionTriggerList: Array<ISaleReturnLineItemPromotionTrigger>;
    saleReturnTaxExemptTrigger: Array<ISaleReturnTaxExemptTrigger>;
    saleReturnLineItemCharacteristicList: Array<ISaleReturnLineItemCharacteristic>;
    saleReturnLineItemModifierCouponList: Array<ISaleReturnLineItemModifierCoupon>;
    saleReturnLineItemModifierReferenceList: Array<ISaleReturnLineItemModifierReference>;
    saleReturnLineItemMerchandiseHierarchyGroupList: Array<ISaleReturnLineItemMerchandiseHierarchyGroup>;
    externalReferenceID: string;
    foodServiceLineItem: string;
    fuelSalesLineItem: string;
    saleReturnLineItemAdditionalPriceList: Array<ISaleReturnLineItemAdditionalPrice>;
    saleReturnLineItemSplitPackageList: Array<ISaleReturnLineItemSplitPackage>;
}
export interface ISaleReturnLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ISaleReturnLineItemSplitPackage extends IDefaultCustoms {
    key: ISaleReturnLineItemSplitPackageKey;
    splitQuantity: number;
}
export interface ISaleReturnLineItemSplitPackageKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    splitPrice: number;
}
export interface ISaleReturnLineItemAdditionalPrice extends IDefaultCustoms {
    key: ISaleReturnLineItemAdditionalPriceKey;
    priceAmount: number;
    packagePriceQuantity: number;
}
export interface ISaleReturnLineItemAdditionalPriceKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    priceTypeCode: string;
}
export interface ISaleReturnLineItemMerchandiseHierarchyGroup extends IDefaultCustoms {
    key: ISaleReturnLineItemMerchandiseHierarchyGroupKey;
    timeStampEffective: string;
    timeStampExpiration: string;
    statusCode: string;
    timeStampEffectiveUTC0: string;
    timeStampExpirationUTC0: string;
}
export interface ISaleReturnLineItemMerchandiseHierarchyGroupKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    merchandiseHierarchyGroupIDQualifier: string;
    merchandiseHierarchyGroupID: string;
}
export interface ISaleReturnLineItemModifierReference extends IDefaultCustoms {
    key: ISaleReturnLineItemModifierReferenceKey;
    referenceQuantity: number;
}
export interface ISaleReturnLineItemModifierReferenceKey extends ITransactionKey {
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    retailTransactionLineItemSequenceNumber: number;
}
export interface ISaleReturnLineItemModifierCoupon extends IDefaultCustoms {
    key: ISaleReturnLineItemModifierCouponKey;
    couponNumber: string;
}
export interface ISaleReturnLineItemModifierCouponKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    modifierSequenceNumber: number;
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    couponSequenceNumber: number;
}
export interface ISaleReturnLineItemCharacteristic extends IDefaultCustoms {
    key: ISaleReturnLineItemCharacteristicKey;
    characteristicValueID: string;
    characteristicValueName: string;
}
export interface ISaleReturnLineItemCharacteristicKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    characteristicID: string;
}
export interface ISaleReturnTaxExemptTrigger extends IDefaultCustoms {
    key: ISaleReturnTaxExemptTriggerKey;
    reasonCode: string;
    reasonDescription: string;
    taxCertificateID: string;
}
export interface ISaleReturnTaxExemptTriggerKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ISaleReturnLineItemPromotionTrigger extends IDefaultCustoms {
    key: ISaleReturnLineItemPromotionTriggerKey;
    triggerType: string;
    triggerValue: string;
    privilegeType: string;
    privilegeValue: number;
    reasonCode: string;
    reasonDescription: string;
    reference_: string;
    triggerSequenceAddend: string;
}
export interface ISaleReturnLineItemPromotionTriggerKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    triggerSequenceNumber: number;
}
export interface IFrequentShopperPointsModifier extends IDefaultCustoms {
    key: IFrequentShopperPointsModifierKey;
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    triggerSequenceNumber: number;
    eligibilityTypeCode: string;
    frequentShopperPointsEarnedCount: number;
    frequentShopperPointsEarnedAmount: number;
    appliedQuantity: number;
    computationBaseAmount: number;
    externalSystemOriginatorFlag: boolean;
    prorateFrom: number;
    pointsPercentage: number;
}
export interface IFrequentShopperPointsModifierKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    frequentShopperPointsModifierSequenceNumber: number;
}
export interface IRetailPriceModifier extends IDefaultCustoms {
    key: IRetailPriceModifierKey;
    promotionID: string;
    priceDerivationRuleID: string;
    priceDerivationRuleEligibilityID: string;
    reasonCode: string;
    previousPrice: number;
    percent: number;
    amount: number;
    calculationMethodCode: string;
    adjustmentMethodCode: string;
    newPrice: number;
    eligibilityTypeCode: string;
    extendedAmountBeforeModification: number;
    extendedAmountAfterModification: number;
    appliedQuantity: number;
    triggerSequenceNumber: number;
    reasonDescription: string;
    extraAmount: number;
    roundingAmount: number;
    externalSystemOriginatorFlag: boolean;
    prorateFrom: number;
    calculationBaseAmount: number;
}
export interface IRetailPriceModifierKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    retailPriceModifierSequenceNumber: number;
}
export interface ILineItemAssociate extends IDefaultCustoms {
    key: ILineItemAssociateKey;
    workerID: string;
    actionDatetime: string;
    workerFirstName: string;
    workerLastName: string;
    actionDatetimeUTC0: string;
}
export interface ILineItemAssociateKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ISaleReturnTaxLineItem extends IDefaultCustoms {
    key: ISaleReturnTaxLineItemKey;
    taxGroupRuleID: string;
    taxIncludedInPricesFlag: boolean;
    taxAtSourceFlag: boolean;
    taxableAmount: number;
    taxablePercent: number;
    taxPercent: number;
    taxAmount: number;
    taxAuthorityID: string;
    taxAuthorityName: string;
    receiptPrintCode: string;
    saleReturnTaxOverrideModifier: Array<ISaleReturnTaxOverrideModifier>;
}
export interface ISaleReturnTaxLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    taxSequenceNumber: number;
}
export interface ISaleReturnTaxOverrideModifier extends IDefaultCustoms {
    key: ISaleReturnTaxOverrideModifierKey;
    taxGroupRuleID: string;
    taxableAmount: number;
    originalTaxAmount: number;
    newTaxAmount: number;
    originalTaxPercent: number;
    newTaxPercent: number;
    reasonCode: string;
    reasonDescription: string;
}
export interface ISaleReturnTaxOverrideModifierKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    taxSequenceNumber: number;
}
export interface ISaleReturnLineItemPrice extends IDefaultCustoms {
    key: ISaleReturnLineItemPriceKey;
    priceAmount: number;
    description: string;
    packagePriceQuantity: number;
}
export interface ISaleReturnLineItemPriceKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    priceTypeCode: string;
}
export interface ISaleReturnLineItemCollection extends IDefaultCustoms {
    key: ISaleReturnLineItemCollectionKey;
    quantity: number;
    units: number;
    receiptText: string;
}
export interface ISaleReturnLineItemCollectionKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    itemID: string;
    itemBaggingUnitOfMeasureCode: string;
}
export interface ISaleReturnLineItemExtension extends IDefaultCustoms {
    key: ISaleReturnLineItemExtensionKey;
    extensionValue: string;
}
export interface ISaleReturnLineItemExtensionKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
    extensionKey: string;
    extensionSequenceNumber: number;
}
export interface ISerializedUnitModifer extends IDefaultCustoms {
    key: ISerializedUnitModiferKey;
    serializedItemID: string;
    serialNumber: string;
}
export interface ISerializedUnitModiferKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface ISaleReturnLineItemSalesOrder extends IDefaultCustoms {
    key: ISaleReturnLineItemSalesOrderKey;
    salesOrderTypeCode: string;
    salesOrderDeliveryTypeCode: string;
    requestedDeliveryDate: string;
}
export interface ISaleReturnLineItemSalesOrderKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IReturnLineItem extends IDefaultCustoms {
    key: IReturnLineItemKey;
    returnReasonCode: string;
    returnReasonDescription: string;
}
export interface IReturnLineItemKey extends ITransactionKey {
    retailTransactionLineItemSequenceNumber: number;
}
export interface IControlTransaction extends IDefaultCustoms {
    key: IControlTransactionKey;
    typeCode: string;
    pOSNoSaleTransaction: Array<IPOSNoSaleTransaction>;
    signOnTransaction: Array<ISignOnTransaction>;
    signOffTransaction: Array<ISignOffTransaction>;
    tillTenderSettlementTransaction: Array<ITillTenderSettlementTransaction>;
    storeSafeSettlementTransaction: Array<IStoreSafeSettlementTransaction>;
    depositBagTransaction: Array<IDepositBagTransaction>;
    depositBagSettlementTransaction: Array<IDepositBagSettlementTransaction>;
    fuelingTransaction: IFuelingTransaction;
    axRefundTransaction: Array<ITaxRefundTransaction>;
}
export interface IControlTransactionKey extends ITransactionKey {
}
export interface ITaxRefundTransaction extends IDefaultCustoms {
    key: ITaxRefundTransactionKey;
    taxRefundDocumentID: string;
    externalTransactionID: string;
    storeInvoiceID: string;
    totalGrossAmount: number;
    totalTaxAmount: number;
    totalRefundAmount: number;
    taxRefundServiceProviderName: string;
}
export interface ITaxRefundTransactionKey extends ITransactionKey {
}
export interface IDepositBagSettlementTransaction extends IDefaultCustoms {
    key: IDepositBagSettlementTransactionKey;
    depositBagID: string;
    depositBagNumber: string;
    depositBagSettlementTenderDetailList: Array<IDepositBagSettlementTenderDetail>;
}
export interface IDepositBagSettlementTransactionKey extends ITransactionKey {
}
export interface IDepositBagSettlementTenderDetail extends IDefaultCustoms {
    key: IDepositBagSettlementTenderDetailKey;
    tenderDescription: string;
    tenderClassCode: string;
    currencySymbol: string;
    exchangeRate: number;
    exchangeRateMultiplyFlag: boolean;
    unitCountRequiredFlag: boolean;
    amountCountRequiredFlag: boolean;
    openBalanceAmount: number;
    openMediaUnitQuantity: number;
    closeBalanceAmount: number;
    foreignCurrencyCloseBalanceAmount: number;
    closeMediaUnitQuantity: number;
    countedBalanceAmount: number;
    foreignCurrencyCountedBalanceAmount: number;
    countedMediaUnitQuantity: number;
    overUnderBalanceAmount: number;
    overUnderMediaUnitQuantity: number;
    iSOCurrencyCode: string;
    depositBagSettlementTenderDenominationList: Array<IDepositBagSettlementTenderDenomination>;
}
export interface IDepositBagSettlementTenderDetailKey extends ITransactionKey {
    tenderTypeCode: string;
}
export interface IDepositBagSettlementTenderDenomination extends IDefaultCustoms {
    key: IDepositBagSettlementTenderDenominationKey;
    typeCode: string;
    pieceValue: number;
    rollFlag: boolean;
    rollCapacity: number;
    denominationCount: number;
    denominationAmount: number;
}
export interface IDepositBagSettlementTenderDenominationKey extends ITransactionKey {
    tenderTypeCode: string;
    denominationSequenceNumber: number;
}
export interface IDepositBagTransaction extends IDefaultCustoms {
    key: IDepositBagTransactionKey;
    depositBagID: string;
    depositBagNumber: string;
}
export interface IDepositBagTransactionKey extends ITransactionKey {
}
export interface IStoreSafeSettlementTransaction extends IDefaultCustoms {
    key: IControlTransactionKeyKey;
    storeSafeSettlementTenderDetailList: Array<IStoreSafeSettlementTenderDetail>;
}
export interface IControlTransactionKeyKey extends ITransactionKey {
}
export interface IStoreSafeSettlementTenderDetail extends IDefaultCustoms {
    key: IStoreSafeSettlementTenderDetailKey;
    openBalanceAmount: number;
    openMediaUnitQuantity: number;
    closeBalanceAmount: number;
    closeMediaUnitQuantity: number;
    countedBalanceAmount: number;
    countedMediaUnitQuantity: number;
    overUnderBalanceAmount: number;
    overUnderMediaUnitQuantity: number;
    currencySymbol: string;
    tenderDescription: string;
    unitCountRequiredFlag: boolean;
    amountCountRequiredFlag: boolean;
    tenderClassCode: string;
    exchangeRate: number;
    exchangeRateMultiplyFlag: boolean;
    foreignCurrencyCountedBalanceAmount: number;
    foreignCurrencyCloseBalanceAmount: number;
    iSOCurrencyCode: string;
    storeSafeSettlementTenderDenominationList: Array<IStoreSafeSettlementTenderDenomination>;
}
export interface IStoreSafeSettlementTenderDetailKey extends ITransactionKey {
    tenderRepositoryID: string;
    tenderTypeCode: string;
}
export interface IStoreSafeSettlementTenderDenomination extends IDefaultCustoms {
    key: IStoreSafeSettlementTenderDenominationKey;
    typeCode: string;
    pieceValue: number;
    rollFlag: boolean;
    rollCapacity: number;
    denominationCount: number;
    denominationAmount: number;
}
export interface IStoreSafeSettlementTenderDenominationKey extends ITransactionKey {
    tenderRepositoryID: string;
    tenderTypeCode: string;
    denominationSequenceNumber: number;
}
export interface ITillTenderSettlementTransaction extends IDefaultCustoms {
    key: ITillTenderSettlementTransactionKey;
    tillSettlementDocument: Array<ITillSettlementDocument>;
    tillSettlementTenderDetailList: Array<ITillSettlementTenderDetail>;
}
export interface ITillTenderSettlementTransactionKey extends ITransactionKey {
}
export interface ITillSettlementTenderDetail extends IDefaultCustoms {
    key: ITillSettlementTenderDetailKey;
    openBalanceAmount: number;
    openMediaUnitQuantity: number;
    closeBalanceAmount: number;
    closeMediaUnitQuantity: number;
    countedBalanceAmount: number;
    countedMediaUnitQuantity: number;
    overUnderBalanceAmount: number;
    overUnderMediaUnitQuantity: number;
    currencySymbol: string;
    tenderDescription: string;
    unitCountRequiredFlag: boolean;
    amountCountRequiredFlag: boolean;
    tenderClassCode: string;
    exchangeRate: number;
    exchangeRateMultiplyFlag: boolean;
    foreignCurrencyCountedBalanceAmount: number;
    foreignCurrencyCloseBalanceAmount: number;
    iSOCurrencyCode: string;
    tillSettlementTenderDenominationList: Array<ITillSettlementTenderDenomination>;
}
export interface ITillSettlementTenderDetailKey extends ITransactionKey {
    tenderRepositoryID: string;
    tenderTypeCode: string;
}
export interface ITillSettlementTenderDenomination extends IDefaultCustoms {
    key: ITillSettlementTenderDenominationKey;
    typeCode: string;
    pieceValue: number;
    rollFlag: boolean;
    rollCapacity: number;
    denominationCount: number;
    denominationAmount: number;
}
export interface ITillSettlementTenderDenominationKey extends ITransactionKey {
    tenderRepositoryID: string;
    tenderTypeCode: string;
    denominationSequenceNumber: number;
}
export interface ITillSettlementDocument extends IDefaultCustoms {
    key: ITillSettlementDocumentKey;
}
export interface ITillSettlementDocumentKey extends ITransactionKey {
    tenderRepositoryID: string;
}
export interface ISignOffTransaction extends IDefaultCustoms {
    key: ISignOffTransactionKey;
    tillID: string;
    lastWorkstationID: string;
    lastWorkerID: string;
    lastWorkerFirstName: string;
    lastWorkerLastName: string;
}
export interface ISignOffTransactionKey extends ITransactionKey {
}
export interface ISignOnTransaction extends IDefaultCustoms {
    key: ISignOnTransactionKey;
    tillID: string;
}
export interface ISignOnTransactionKey extends ITransactionKey {
}
export interface IPOSNoSaleTransaction extends IDefaultCustoms {
    key: IPOSNoSaleTransactionKey;
    tillID: string;
}
export interface IPOSNoSaleTransactionKey extends ITransactionKey {
}
export interface IFuelingTransaction extends IDefaultCustoms {
    key: IFuelingTransactionKey;
    itemID: string;
    fuelingPointID: number;
    nozzleID: number;
    typeCode: string;
    timeStamp: string;
    timeStampUTC0: string;
    volume: number;
    unitPrice: number;
    authorizationElapsedTime: number;
    deliveryElapsedTime: number;
    saleElapsedTime: number;
    fuelGradeID: string;
    unitOfMeasureCode: string;
    fleetCardPermissionTypeCode: string;
    testDeliveryTypeCode: string;
    driveOffTypeCode: string;
}
export interface IFuelingTransactionKey extends ITransactionKey {
}
export interface ITenderControlTransaction extends IDefaultCustoms {
    key: ITenderControlTransactionKey;
    tenderControlTypeCode: string;
    tenderPickupTransaction: Array<ITenderPickupTransaction>;
    tenderLoanTransaction: Array<ITenderLoanTransaction>;
    tenderAmountAdjustmentTransaction: Array<ITenderAmountAdjustmentTransaction>;
    tenderDepositReceiptTransaction: Array<ITenderDepositReceiptTransaction>;
    tenderControlTransactionTenderLineItemList: Array<ITenderControlTransactionTenderLineItem>;
}
export interface ITenderControlTransactionKey extends ITransactionKey {
}
export interface ITenderControlTransactionTenderLineItem extends IDefaultCustoms {
    key: ITenderControlTransactionTenderLineItemKey;
    foreignCurrencyAmount: number;
    amount: number;
    count: number;
    tenderControlTransactionTenderLineItemDenominationList: Array<ITenderControlTransactionTenderLineItemDenomination>;
    iSOCurrencyCode: string;
    currencySymbol: string;
    tenderDescription: string;
    unitCountRequiredFlag: boolean;
    amountCountRequiredFlag: boolean;
    tenderClassCode: string;
    exchangeRate: number;
    exchangeRateMultiplyFlag: boolean;
}
export interface ITenderControlTransactionTenderLineItemKey extends ITransactionKey {
    tenderTypeCode: string;
}
export interface ITenderControlTransactionTenderLineItemDenomination extends IDefaultCustoms {
    key: ITenderControlTransactionTenderLineItemDenominationKey;
    typeCode: string;
    pieceValue: number;
    rollFlag: boolean;
    rollCapacity: number;
    denominationCount: number;
    denominationAmount: number;
}
export interface ITenderControlTransactionTenderLineItemDenominationKey extends ITransactionKey {
    tenderTypeCode: string;
    denominationSequenceNumber: number;
}
export interface ITenderDepositReceiptTransaction extends IDefaultCustoms {
    key: ITenderDepositReceiptTransactionKey;
    outboundTenderRepositoryID: string;
    inboundTenderRepositoryID: string;
    depositBagID: string;
    depositBagNumber: string;
    safeTenderMovementCode: string;
    doubleCheckingWorkerID: string;
}
export interface ITenderDepositReceiptTransactionKey extends ITransactionKey {
}
export interface ITenderAmountAdjustmentTransaction extends IDefaultCustoms {
    key: ITenderAmountAdjustmentTransactionKey;
    tillID: string;
}
export interface ITenderAmountAdjustmentTransactionKey extends ITransactionKey {
}
export interface ITenderLoanTransaction extends IDefaultCustoms {
    key: ITenderLoanTransactionKey;
    outboundSafeID: string;
    inboundTillID: string;
}
export interface ITenderLoanTransactionKey extends ITransactionKey {
}
export interface ITenderPickupTransaction extends IDefaultCustoms {
    key: ITenderPickupTransactionKey;
    inboundSafeID: string;
    outboundTillID: string;
    envelopeID: string;
}
export interface ITenderPickupTransactionKey extends ITransactionKey {
}
export interface ITransactionAuditEvent extends IDefaultCustoms {
    key: ITransactionAuditEventKey;
    creationTimestamp: string;
    creationTimestampUTC0: string;
    workstationID: string;
    workstationTypeCode: string;
    eventTypeCode: string;
    content: any;
}
export interface ITransactionAuditEventKey extends ITransactionKey {
    eventSequenceNumber: number;
}
export interface IRetailTransactionCustomer extends IDefaultCustoms {
    key: IRetailTransactionCustomerKey;
    genderType: string;
    birthDayNumber: number;
    birthMonthNumber: number;
    birthYearNumber: number;
    addressTypeDescription: string;
    genericFlag: boolean;
    businessDescription: string;
    customerIDEntryMethodCode: string;
    firstName: string;
    lastName: string;
    preferredReceiptPrintoutTypeCode: string;
    parentCustomerID: string;
    parentCustomerName1: string;
    parentCustomerName2: string;
    organizationName: string;
    retailTransactionCustomerAccountList: Array<IRetailTransactionCustomerAccount>;
    retailTransactionCustomerGroupAssignmentList: Array<IRetailTransactionCustomerGroupAssignment>;
    retailTransactionCustomerContactMethodList: Array<IRetailTransactionCustomerContactMethod>;
    retailTransactionCustomerIdentificationList: Array<IRetailTransactionCustomerIdentification>;
}
export interface IRetailTransactionCustomerKey extends ITransactionKey {
    customerID: string;
    addressTypeCode: string;
}
export interface IRetailTransactionCustomerAccount extends IDefaultCustoms {
    key: IRetailTransactionCustomerAccountKey;
    customerAccountID: string;
    customerAccountTypeCode: string;
    customerAccountBalance: number;
    customerAccountQuerySuccessfulFlag: boolean;
    customerAccountTransactionID: string;
}
export interface IRetailTransactionCustomerAccountKey extends IRetailTransactionCustomerKey {
    customerAccountSequenceNumber: number;
}
export interface IRetailTransactionCustomerGroupAssignment extends IDefaultCustoms {
    key: IRetailTransactionCustomerGroupAssignmentKey;
}
export interface IRetailTransactionCustomerGroupAssignmentKey extends IRetailTransactionCustomerKey {
    customerGroupID: string;
}
export interface IRetailTransactionCustomerContactMethod extends IDefaultCustoms {
    key: IRetailTransactionCustomerContactMethodKey;
    contactTypeCode: string;
    emailAddressLocalPart: string;
    emailAddressDomainPart: string;
    completePhoneNumber: string;
    internetURL: string;
    addressLine1: string;
    addressLine2: string;
    addressLine3: string;
    addressLine4: string;
    addressLine5: string;
    city: string;
    subTerritoryName: string;
    postalCode: string;
    postalCodeExtension: string;
    territory: string;
    territoryName: string;
    iSOCountryCode: string;
}
export interface IRetailTransactionCustomerContactMethodKey extends IRetailTransactionCustomerKey {
    contactPurposeTypeCode: string;
    contactMethodTypeCode: string;
}
export interface IRetailTransactionCustomerIdentification extends IDefaultCustoms {
    key: IRetailTransactionCustomerIdentificationKey;
    identifier: string;
}
export interface IRetailTransactionCustomerIdentificationKey extends IRetailTransactionCustomerKey {
    partyIdentificationTypeCode: string;
}
